@@ -51,7 +51,7 @@ class Controllers():
         # Calculate id if necessary
         if not id:
             title = body['name']
-            title = title + ' ' + hex(int(time.time()))[2:]
+            title = title[:80] + ' ' + hex(int(time.time()))[2:]
             id = slugify.slugify(title, separator='-', lowercase=True)
         body['id'] = id
 
@@ -180,6 +180,15 @@ class Controllers():
         run = trigger_dag(id)
         return dict(result=run.run_id if run else None) 
 
+    def start_pipelines(self, kind, all_pipelines):
+        count = 0
+        for pipeline in self.query_pipelines()['result']:
+            if pipeline['kind'] == kind:
+                if all_pipelines or pipeline['status']['status'] == 'success':
+                    Controllers.start_pipeline(pipeline['id'])
+                    count += 1
+        return dict(success=True, started=count)
+
     @staticmethod
     def trigger_event(event, pipeline):
         from airflow.api.common.experimental.trigger_dag import trigger_dag
