@@ -1,4 +1,5 @@
-from dgp_oauth2.models import get_user, delete_user
+import os
+from dgp_oauth2.models import Models as AuthModels
 
 from .models import Models
 
@@ -7,6 +8,7 @@ class Controllers():
 
     def __init__(self, connection_string):
         self.models = Models(connection_string=connection_string)
+        self.authModels = AuthModels(os.environ.get('DATABASE_URL'))
 
     def create_or_edit_user(self, id, body):
         ret = self.models.create_or_edit(id, body)
@@ -14,12 +16,12 @@ class Controllers():
 
     def delete_user(self, id):
         ret = self.models.delete(id)
-        auth_delete = delete_user(id)
+        auth_delete = self.authModels.delete_user(id)
         ret['success'] = ret['success'] or auth_delete
         return ret
 
     def query_users(self, userid):
-        user = get_user(userid)
+        user = self.authModels.get_user(userid)
         if user is None:
             return {}
 
